@@ -25,7 +25,7 @@ PeriodicTableScene::PeriodicTableScene(QObject *parent)
     , m_prevHoverElement(-1)
 {
     QPalette widgetPalette = palette();
-    setBackgroundBrush(QBrush(widgetPalette.window()));
+    setBackgroundBrush(QBrush(widgetPalette.base()));
 
     setItemIndexMethod(QGraphicsScene::NoIndex);
 
@@ -37,6 +37,12 @@ PeriodicTableScene::~PeriodicTableScene() = default;
 
 bool PeriodicTableScene::event(QEvent *e)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() ==  QEvent::ApplicationPaletteChange) {
+        QPalette widgetPalette = qApp->palette();
+        setBackgroundBrush(QBrush(widgetPalette.base()));
+    }
+#endif
     return QGraphicsScene::event(e);
 }
 
